@@ -77,20 +77,19 @@ void fileSelDialogOk(GtkWidget *widget, GtkFileSelection *fs )
 #else
 void fileSelDialogOk(GtkWidget *widget) {
 	GSList *z1,*z2;
-	int i1;
 	gchar *entry[1][1];
 
 	z1=gtk_file_chooser_get_filenames((GtkFileChooser *)widget);
 	z2=z1;
-	i1=0;
 	while(z1 != (GSList *)NULL) {
 		if(filesToPrintAnz >= MAXPRINTFILES) {
 			gtk_widget_set_sensitive(fileAdd,FALSE);
 		} else {
 			strncpy(filesToPrint[(unsigned char)filesToPrintAnz],(char *)z1->data,(size_t)MAXPATH);
-			entry[0][0]=filesToPrint[(unsigned char)filesToPrintAnz];
+			entry[0][0]=g_filename_to_utf8(filesToPrint[(unsigned char)filesToPrintAnz],-1,NULL,NULL,NULL);
 			filesToPrintAnz++;
 			gtk_clist_append(GTK_CLIST(fileList),entry[0]);
+			g_free(entry[0][0]);
 			if(filesToPrintAnz >= MAXPRINTFILES)
 				gtk_widget_set_sensitive(fileAdd,FALSE);
 			else
@@ -136,9 +135,10 @@ void fileSelDialogDestroyed(GtkWidget *widget, gpointer data )
 				gtk_widget_set_sensitive(fileAdd,FALSE);
 			} else {
 				strncpy(filesToPrint[filesToPrintAnz],z1[i1],(size_t)MAXPATH);
-	    	filesToPrintAnz++;
-				entry[0][0]=z1[i1];
+				filesToPrintAnz++;
+				entry[0][0]=g_filename_to_utf8(z1[i1],-1,NULL,NULL,NULL);
 				gtk_clist_append(GTK_CLIST(fileList),entry[0]);
+				g_free(entry[0][0]);
 				gtk_widget_set_sensitive(fileRemoveAll,TRUE);
 			}
 		}
@@ -289,8 +289,8 @@ void fileAddPressed(GtkWidget *widget,gpointer data)
 #ifdef OLDDIALOG
 	gtk_file_selection_set_filename (GTK_FILE_SELECTION(fileRequ),fileOpenPath);
 	gtk_file_selection_hide_fileop_buttons(GTK_FILE_SELECTION(fileRequ));	
-  gtk_window_set_modal(GTK_WINDOW(fileRequ),TRUE);
-  gtk_window_set_modal(GTK_WINDOW(mainWindow),FALSE);
+	gtk_window_set_modal(GTK_WINDOW(fileRequ),TRUE);
+	gtk_window_set_modal(GTK_WINDOW(mainWindow),FALSE);
 	gtk_window_set_position(GTK_WINDOW(fileRequ),GTK_WIN_POS_CENTER);
 
 	gtk_entry_set_editable(GTK_ENTRY(((GtkFileSelection *)fileRequ)->selection_entry),FALSE);
@@ -379,12 +379,10 @@ void fileRemoveFromList(char *file)
 void FileFrame(GtkWidget *container)
 {
 	GtkWidget *mainHBox,*vbox,*buttonBox,*scrolled;
-	gchar *entry[1][1],name[MAXPATH+1];
+	gchar *entry[1][1];
 
 	int i1;
 
-	entry[0][0]=name;
-
 	mainHBox=gtk_hbox_new(FALSE,0);
 	gtk_box_pack_start(GTK_BOX(container), mainHBox, FALSE, FALSE, FRAME_SPACING_V);
 	gtk_widget_show(mainHBox);
@@ -409,8 +407,9 @@ void FileFrame(GtkWidget *container)
 
 	for(i1 = 0; i1 < filesToPrintAnz; i1++)
 	{
-		strncpy(name,filesToPrint[i1],(size_t)MAXPATH);
+		entry[0][0]=g_filename_to_utf8((gchar *)filesToPrint[i1],(size_t)MAXPATH,NULL,NULL,NULL);
 		gtk_clist_append(GTK_CLIST(fileList),entry[0]);
+		g_free(entry[0][0]);
 	}
 	fileSelectedEntry=-1;
 
