@@ -261,6 +261,11 @@ void PrinterChanged(GtkWidget *widget,gpointer data)
 		if(DEBUG) printf("Skipping emptry selection !\n");
 		return;
 	}
+	if (!strcmp(tmp, "-----"))
+	{
+		gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(printerFrameCombo)->entry), PrinterNames[PrinterChoice]);
+		return;
+	}
 
 	merkconflict=conflict_active;
 	conflict_active=0;
@@ -293,7 +298,7 @@ void PrinterChanged(GtkWidget *widget,gpointer data)
 	{
 			gtk_entry_set_text(GTK_ENTRY(GTK_COMBO(printerFrameCombo)->entry), PrinterNames[lastPrinterChoice]);
 	}
-	if(ret == 0)  /* OK, printer has ppd */
+	else if(ret == 0)  /* OK, printer has ppd */
 	{
 		getOptions(tmp,0);
 		gtk_widget_hide(tabs);
@@ -558,6 +563,182 @@ void callGtkLPQFunc(GtkButton *button, gpointer data) {
 	system(GTKLPQCOM);
 }
 
+void recreatePrinterList(void) {
+        GList *printerList=NULL;
+        int i1;
+
+       	if(DEBUG)
+       	        printf("Recreating printer list\n");
+ 	for(i1=0; PrinterFavNames[i1][0] != (uintptr_t)NULL; i1++)
+ 	{
+        	if(DEBUG)
+        	        printf("Adding favorite %s to printer list\n", PrinterFavNames[i1]);
+		printerList=g_list_append(printerList,str2str(PrinterFavNames[i1]));
+	}
+	if(PrinterFavNames[0][0] != (uintptr_t)NULL)
+		printerList=g_list_append(printerList,"-----");
+ 	for(i1=0; i1<=PrinterNum; i1++)
+	{
+		printerList=g_list_append(printerList,str2str(PrinterNames[i1]));
+	}
+	gtk_combo_set_popdown_strings (GTK_COMBO(printerFrameCombo),printerList);
+}
+
+void loadFavorites(void)
+{
+	char *home;
+
+	/* load */
+	home = getenv("HOME");
+	if (home)
+	{
+        	FILE *file = NULL;
+        	char filepath[MAXPATH+1];
+
+        	snprintf(filepath,(size_t)MAXPATH,"%s/favorites",confdir);
+                if(PrinterFavNames[0][0] != (uintptr_t)NULL)
+                        memset(PrinterFavNames, 0, sizeof(PrinterFavNames));
+       	        if(DEBUG)
+               	        printf("Load favorites from %s\n", filepath);
+               	file = fopen(filepath, "r");
+               	if(file)
+               	{
+                       	int i1=0;
+                       	while(fscanf(file, "%s", PrinterFavNames[i1]) > 0)
+                       	{
+                       	        if(DEBUG)
+                               	        printf("%u: %s\n", i1, PrinterFavNames[i1]);
+                       		i1++;
+                       	}
+               	        fclose(file);
+                	if(DEBUG)
+                	        printf("%u Favorites loaded.\n", i1);
+                        checkFavorites();
+                }
+                else
+                {
+                	if(DEBUG)
+                	        printf("Could not open favorites file\n");
+                }
+	}
+}
+
+void saveFavorites(void)
+{
+	char *home;
+
+	/* save */
+	home = getenv("HOME");
+	if (home)
+	{
+        	FILE *file = NULL;
+        	char filepath[MAXPATH+1];
+
+        	snprintf(filepath,(size_t)MAXPATH,"%s/favorites",confdir);
+        	if(DEBUG)
+        	        printf("Favorites now:\n");
+                if(PrinterFavNames[0][0] != (uintptr_t)NULL)
+                {
+                        int i1;
+
+               	        if(DEBUG)
+                       	        printf("Save to %s\n", filepath);
+                	file = fopen(filepath, "w");
+                	i1=0;
+                	while(PrinterFavNames[i1][0] != (uintptr_t)NULL)
+                	{
+                	        if(DEBUG)
+                        	        printf("%u: %s\n", i1, PrinterFavNames[i1]);
+                	        if(file)
+                        	        fprintf(file, "%s\n", PrinterFavNames[i1]);
+                		i1++;
+                	}
+               	        if(file)
+                       	        fclose(file);
+                }
+                else
+                {
+               	        if(DEBUG)
+                       	        printf("Delete %s\n", filepath);
+                        unlink(filepath);
+                }
+	}
+}
+
+void callAddFavFunc(GtkButton *button, gpointer data) {
+        int found;
+        int i1;
+	char tmp[DEF_PRN_LEN+1];
+
+	snprintf(tmp,(size_t)DEF_PRN_LEN,"%s",gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(printerFrameCombo)->entry)));
+       	/* Add to favorites, if not yet there */
+       	i1=0;
+       	found=0;
+       	while(PrinterFavNames[i1][0] != (uintptr_t)NULL)
+       	{
+       		if(strcmp(tmp,str2str(PrinterFavNames[i1])) == 0)
+      		{
+        		if(DEBUG)
+        			printf("Printer %s already in favorites\n", tmp);
+       			found = 1;
+       			break;
+       		}
+		i1++;
+	}
+	if (!found && (i1 < MAX_PRT))
+	{
+	        strcpy(PrinterFavNames[i1], tmp);
+       		if(DEBUG)
+       			printf("Printer %s added to favorites\n", tmp);
+        	recreatePrinterList();
+        	saveFavorites();
+	}
+}
+
+void callRmFavFunc(GtkButton *button, gpointer data) {
+        int found;
+        int i1;
+	char tmp[DEF_PRN_LEN+1];
+
+	snprintf(tmp,(size_t)DEF_PRN_LEN,"%s",gtk_entry_get_text(GTK_ENTRY(GTK_COMBO(printerFrameCombo)->entry)));
+       	/* Remove from favorites, if there */
+       	i1=0;
+       	found=0;
+       	while(PrinterFavNames[i1][0] != (uintptr_t)NULL)
+       	{
+       		if(strcmp(tmp,str2str(PrinterFavNames[i1])) == 0)
+      		{
+       			found = 1;
+       			break;
+       		}
+		i1++;
+	}
+	if (found)
+	{
+       	        /* find last entry and move here */
+       	        unsigned i2;
+
+       		if(DEBUG)
+       			printf("Remove %s from favorites\n", PrinterFavNames[i1]);
+       	        i2 = i1 + 1;
+       	        while (PrinterFavNames[i2][0])
+       	                i2++;
+                i2--;
+                if (i2 != i1)
+                {
+                        strcpy(PrinterFavNames[i1], PrinterFavNames[i2]);
+                }
+                PrinterFavNames[i2][0] = 0;
+        	recreatePrinterList();
+        	saveFavorites();
+	}
+	else
+	{
+       		if(DEBUG)
+       			printf("Printer %s not in favorites\n", tmp);
+	}
+}
+
 void PrinterCallGtklpq(GtkWidget *container)
 {
 	GtkWidget *hbox, *gtklpqbutton;
@@ -581,9 +762,9 @@ void PrinterCallGtklpq(GtkWidget *container)
 
 void PrinterFrame(GtkWidget *container)
 {
-	GtkWidget *mainHBox,*hbox,*vbox;
-	GList *printerList=NULL;
-	int i1;
+	GtkWidget *mainHBox,*hbox,*vbox,*vboxp,*hboxfav,*addfavbutton, *rmfavbutton;
+
+	loadFavorites();
 
 	mainHBox=gtk_hbox_new(FALSE,INFRAME_SPACING_H);
 	gtk_box_pack_start(GTK_BOX(container), mainHBox, FALSE, FALSE, FRAME_SPACING_V);	
@@ -598,20 +779,38 @@ void PrinterFrame(GtkWidget *container)
         gtk_container_add(GTK_CONTAINER(printerFrame), hbox);
         gtk_widget_show(hbox);
 
+	/* Printer select vbox */
+	vboxp=gtk_vbox_new(FALSE,0);	
+	gtk_box_set_spacing(GTK_BOX(vboxp),0);
+	gtk_box_pack_start(GTK_BOX(hbox), vboxp, FALSE, FALSE,0);
+	gtk_widget_show(vboxp);
+
 	printerFrameCombo=gtk_combo_new();
 
-	for(i1=0; i1<=PrinterNum; i1++)
-	{
-		printerList=g_list_append(printerList,str2str(PrinterNames[i1]));
-	}
-	gtk_combo_set_popdown_strings (GTK_COMBO(printerFrameCombo),printerList);
+	recreatePrinterList();
 	gtk_combo_set_value_in_list(GTK_COMBO(printerFrameCombo),TRUE,FALSE);
 	gtk_list_set_selection_mode(GTK_LIST(GTK_COMBO(printerFrameCombo)->list),GTK_SELECTION_SINGLE);
 
 	gtk_entry_set_editable(GTK_ENTRY(GTK_COMBO(printerFrameCombo)->entry),FALSE); 
-	gtk_box_pack_start(GTK_BOX(hbox), printerFrameCombo, FALSE, FALSE, 0);
+	gtk_box_pack_start(GTK_BOX(vboxp), printerFrameCombo, FALSE, FALSE, 0);
 	gtk_widget_show(printerFrameCombo);
 
+	/* Favorites hbox */
+	hboxfav=gtk_hbox_new(FALSE,INFRAME_SPACING_H);
+	gtk_box_pack_end(GTK_BOX(vboxp), hboxfav, FALSE, FALSE, 0);
+	gtk_widget_show(hboxfav);
+	/* Add Favorites Button */
+	addfavbutton=gtk_button_new_with_label(str2str(_("Add favorite")));
+	gtk_box_pack_start(GTK_BOX(hboxfav), addfavbutton, FALSE, TRUE,0);
+	gtk_widget_show(addfavbutton);
+	gtk_signal_connect(GTK_OBJECT(GTK_BUTTON(addfavbutton)),"clicked",GTK_SIGNAL_FUNC(callAddFavFunc),NULL);
+
+	/* Remove Favorites Button */
+	rmfavbutton=gtk_button_new_with_label(str2str(_("Remove favorite")));
+	gtk_box_pack_end(GTK_BOX(hboxfav), rmfavbutton, FALSE, TRUE,0);
+	gtk_widget_show(rmfavbutton);
+	gtk_signal_connect(GTK_OBJECT(GTK_BUTTON(rmfavbutton)),"clicked",GTK_SIGNAL_FUNC(callRmFavFunc),NULL);
+
 	/* InfoBoxen */
 	vbox=gtk_vbox_new(FALSE,0);	
 	gtk_box_set_spacing(GTK_BOX(vbox),0);
