@@ -111,7 +111,6 @@ char BROWSER[MAXPATH+1];
 char HELPURL[MAXPATH+1];
 char GTKLPQCOM[MAXPATH+1];
 int textwrap;
-char PortString[MAX_PORT+11];
 int hasAskedPWD;
 ppd_file_t *printerPPD;
 int PPDopen;
@@ -136,9 +135,9 @@ int main(int argc,char *argv[])
 	int calledLpr;
 	int calledLp;
 	int forceX;
-	char Path[MAXPATH+1];
 	char *z1;
 	char tmpenv[MAX_SERVER_NAME+13];
+	struct stat snstat;
 
 #if GTK_MAJOR_VERSION != 1
 	progressBar=(GtkWidget *)NULL;
@@ -215,8 +214,9 @@ int main(int argc,char *argv[])
 	DEF_PRN[0]=(uintptr_t)NULL;
 	confdir[0]=(uintptr_t)NULL;
 	ServerName[0]=(uintptr_t)NULL;
+	PortString[0]=(uintptr_t)NULL;
+	ServerAddr[0]=(uintptr_t)NULL;
 	UserName[0]=(uintptr_t)NULL;
-	Path[0]=(uintptr_t)NULL;
 	ReallyPrint=1;
 	needFileSelection = 1;
 	cmdNumCopies=-1;
@@ -249,7 +249,7 @@ int main(int argc,char *argv[])
 		gtk_signal_connect (GTK_OBJECT (mainWindow), "delete_event",GTK_SIGNAL_FUNC (destroy), NULL);
 		gtk_signal_connect (GTK_OBJECT (mainWindow), "destroy",GTK_SIGNAL_FUNC (destroy), NULL);
 		gtk_container_set_border_width (GTK_CONTAINER (mainWindow), 10);
-		gtk_widget_show(mainWindow);
+		// XXXX gtk_widget_show(mainWindow);
 		gtk_widget_realize(mainWindow);
 
 		/* Vertikaler Container im HauptFenster */
@@ -581,6 +581,21 @@ int main(int argc,char *argv[])
 		}
 		strncpy(ServerName,z1,(size_t)MAX_SERVER_NAME);
 	}
+	/* Set server location */
+	if ((stat(ServerName,&snstat) == 0) && S_ISSOCK(snstat.st_mode)) {
+	/* Unix socket */
+	    if (PortString[0]) { /* port specified */
+	        sprintf(ServerAddr,"127.0.0.1:%s",PortString+9);
+	    } else {
+	        sprintf(ServerAddr,"127.0.0.1:%d",ippPort());
+	    }
+	} else {
+	    if (PortString[0]) { /* port specified */
+	        sprintf(ServerAddr,"%s:%s",ServerName,PortString+9);
+	    } else {
+	        strcpy(ServerAddr,ServerName);
+	    }
+	}
 	if(DEBUG)
 		printf("ServerName: %s\nTry to connect...\n",ServerName);
 	cupsHttp=httpConnect(ServerName, ippPort());
@@ -731,7 +746,7 @@ int main(int argc,char *argv[])
 #endif
 
 		/* Fenster anzeigen */
-		gtk_widget_hide(mainWindow);
+		// XXX gtk_widget_hide(mainWindow);
 		gtk_widget_hide(waitLabel);
 #if GTK_MAJOR_VERSION != 1
 		gtk_widget_hide(progressBar);
