@@ -167,14 +167,14 @@ void getBannerList(char *printername)
 	if(z1 != NULL)
 		*z1=(uintptr_t)NULL;
 
-	snprintf(URI,(size_t)MAX_URI,"ipp://%s/printers/%s",ServerName,printername);
+	snprintf(URI,(size_t)MAX_URI,"ipp://%s/printers/%s",ServerAddr,printername);
 
 	if(z1 != NULL)
 		*z1='/';
 
 	request=ippNew();
-	request->request.op.operation_id=IPP_GET_PRINTER_ATTRIBUTES;
-	request->request.op.request_id=1;
+	ippSetOperation(request, IPP_GET_PRINTER_ATTRIBUTES);
+	ippSetRequestId(request, 1);
 	ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_CHARSET,"attributes-charset",NULL,cupsLangEncoding(cupsLanguage));
 	ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_LANGUAGE,"attributes-natural-language",NULL,cupsLanguage->language);
 	ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_URI,"printer-uri",NULL,URI);
@@ -194,7 +194,7 @@ void getBannerList(char *printername)
 	}
 	else
 	{
-		bannerAnz=attr->num_values;
+		bannerAnz=ippGetCount(attr);
 		if(bannerAnz > MAX_BANNER)
 		{
 			if(DEBUG)
@@ -206,8 +206,8 @@ void getBannerList(char *printername)
 		for(i1=0;i1<bannerAnz;i1++)
 		{
 			if(DEBUG)
-				printf("  %s\n",attr->values[i1].string.text);
-			strncpy(Banners[i1],(char *)attr->values[i1].string.text,(size_t)MAXLINE);
+			printf("  %s\n",ippGetString (attr, i1, NULL));
+			strncpy(Banners[i1],(char *)ippGetString (attr, i1, NULL),(size_t)MAXLINE);
 			bannerList=g_list_append(bannerList,(gchar *)str2str(Banners[i1]));
 		}
 	}
@@ -216,7 +216,7 @@ void getBannerList(char *printername)
 
 void getOptions(char *printername,int which)
 {
-	int i1,hasrc,nohome,ppdOptAnz;
+	int i1,hasrc,nohome;
 	int needNew=0;
 	int whichfile=0;
 	char printpath[MAXPATH+1],globalpath[MAXPATH+1];
@@ -264,7 +264,6 @@ void getOptions(char *printername,int which)
 	if(!builtin)
 	{
 		nohome=0;
-		ppdOptAnz=-1;
 		printpath[0]=(uintptr_t)NULL;
 		globalpath[0]=(uintptr_t)NULL;
 		printpath_g[0]=(uintptr_t)NULL;
@@ -1891,10 +1890,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 	cups_option_t **optionsptr;	
 	const char *files[MAXPRINTFILES];
 	char tmpprn[DEF_PRN_LEN+1];
-  char *spoolfile;
-	
-	for(i1=0;i1<=filesToPrintAnz;i1++)
-		files[i1]=filesToPrint[i1];
+	char *spoolfile;
 	
 	num_options=0;
 	options=(cups_option_t *)0;
@@ -1911,6 +1907,9 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 	{
 		if(filesToPrintAnz > 0)
 		{
+			for(i1=0;i1<filesToPrintAnz;i1++)
+				files[i1]=(char *)g_filename_to_utf8((gchar *)filesToPrint[i1],-1,NULL,NULL,NULL);
+
 			if(DEBUG)  printf("NumOpts-final(printing from file): %i\n",num_options);
 			if(JobName[0] != (uintptr_t)NULL)
 			{
@@ -1918,30 +1917,31 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 			}
 			else
 			{
-					for(i1=0;i1<filesToPrintAnz;i1++)
-					{
-						z1=strrchr(files[i1],'/');
-						if(z1==(char *)NULL)
-							z1=(char *)files[i1];
-						else
-							z1++;
-						jobid=cupsPrintFile(tmpprn,files[i1],z1,num_options,options);
-					
-						if(jobid <= 0)
-							g_print("\n%s\n\n",str2str(_("Unable to print,\nunknown file format!")));
-						if(DEBUG)
-							printf("Job-ID: %i\n",jobid);
-						if(jobidonexit)
-							g_print("%s: %i\n",str2str(_("JobID")),jobid);
-					}
+				for(i1=0;i1<filesToPrintAnz;i1++)
+				{
+					z1=strrchr(files[i1],'/');
+					if(z1==(char *)NULL)
+						z1=(char *)files[i1];
+					else
+						z1++;
+					jobid=cupsPrintFile(tmpprn,files[i1],z1,num_options,options);
+
+					if(jobid <= 0)
+						g_print("\n%s\n\n",str2str(_("Unable to print,\nunknown file format!")));
+					if(DEBUG)
+						printf("Job-ID: %i\n",jobid)   ;
+					if(jobidonexit)
+						g_print("%s: %i\n",str2str(_("JobID")),jobid);
+				}
 			}
 			cupsFreeOptions(num_options,options);
+			for(i1=0;i1<filesToPrintAnz;i1++)
+				g_free((char *)files[i1]);
 		}
 		else
 		{
 			quick_message(str2str(_("Dont know what to print!")),2);
 			return;
-
 		}
                 if(exitonprint || (needFileSelection==0))
                         gtklp_end();
@@ -1953,7 +1953,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
         {
                 if(DEBUG)  printf("NumOpts-final(printing from stdin): %i\n",num_options);
 
-                spoolfile=cupsTempFile(tmppath,sizeof(tmppath));
+                spoolfile=(char*)cupsTempFile2(tmppath,sizeof(tmppath));
 
                 if(spoolfile == (uintptr_t)NULL)
                 {
@@ -1965,7 +1965,7 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 		{
 			if(DEBUG)
 				printf("Spoolfile: %s\n",tmppath);
-    	spool=fopen(spoolfile, "w");                                                                                     
+			spool=fopen(tmppath, "w");                                                                                     
 			if(spool==(FILE *)NULL)
 			{
 				if(DEBUG)
@@ -1974,32 +1974,30 @@ void PrintFunc( GtkWidget *widget,gpointer   data )
 			}
 			else
 			{
-    				while ((i1 = fread(tmp, 1, sizeof(tmp), stdin)) > 0)                                                                                        
+				while ((i1 = fread(tmp, 1, sizeof(tmp), stdin)) > 0)                                                                                        
 					fwrite(tmp, 1, i1, spool);                                                                                                                    
-    				i1 = ftell(spool);                                                                                                                                 
-    				fclose(spool);                                                                                                                                    
+				i1 = ftell(spool);                                                                                                                                 
+				fclose(spool);                                                                                                                                    
 				if(i1 == 0)
 				{
 					if(DEBUG)
 						printf("PROG-ERROR: Data on stdin, but empty...\n");
 					emergency();
 				}
-					
-					if(JobName[0] != (uintptr_t)NULL)
-						jobid=cupsPrintFile(tmpprn,spoolfile,JobName,num_options,options);
-					else
-	          jobid=cupsPrintFile(tmpprn,spoolfile,str2str(_("(stdin)")),num_options,options);
-                			if(jobid <= 0)
-											{
-                        			g_print("\n%s\n\n",str2str(_("Unable to print!")));
-											}
- 		                	if(DEBUG)
-                	        		printf("Job-ID: %i\n",jobid);
-                                	if(jobidonexit)
-                                        	g_print("%s: %i\n",str2str(_("JobID")),jobid);
+
+				if(JobName[0] != (uintptr_t)NULL)
+					jobid=cupsPrintFile(tmpprn,tmppath,JobName,num_options,options);
+				else
+					jobid=cupsPrintFile(tmpprn,tmppath,str2str(_("(stdin)")),num_options,options);
+				if(jobid <= 0)
+					g_print("\n%s\n\n",str2str(_("Unable to print!")));
+				if(DEBUG)
+					printf("Job-ID: %i\n",jobid);
+				if(jobidonexit)
+					g_print("%s: %i\n",str2str(_("JobID")),jobid);
 
 
-		                cupsFreeOptions(num_options,options);
+				cupsFreeOptions(num_options,options);
 				unlink(tmppath);
 
                 		if(exitonprint || (needFileSelection==0))
@@ -2091,7 +2089,6 @@ void constraints(int prob)
 	GdkPixmap *rightpixmap;
 	GdkBitmap *mask;
 	GtkStyle *style;
-	GtkWidget *button;
 #if GTK_MAJOR_VERSION == 1
 	GtkWidget *ruler;
 	GtkWidget *buttonbox;
@@ -2109,7 +2106,6 @@ void constraints(int prob)
 	gtk_window_set_position(GTK_WINDOW(constwin),GTK_WIN_POS_MOUSE);
 #else
 	constwin=gtk_dialog_new_with_buttons(str2str(_("Conflicts")),GTK_WINDOW(mainWindow),GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,NULL);
-	button=gtk_dialog_add_button(GTK_DIALOG(constwin),GTK_STOCK_OK,0);
 	gtk_dialog_set_default_response(GTK_DIALOG(constwin),0);
 #endif
 
@@ -2330,7 +2326,6 @@ void instWin(GtkWidget *widget, gpointer data)
 	GtkWidget *buttonbox;
 	GtkWidget *button_inst_save;
 #endif
-	GtkWidget *button_inst_cancel;
 	GtkWidget *printer;
 	GtkWidget *instance;
 	GtkWidget *entrystable;
@@ -2357,7 +2352,6 @@ void instWin(GtkWidget *widget, gpointer data)
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(instwin)->vbox), hbox);
 	button_inst_save=gtk_dialog_add_button(GTK_DIALOG(instwin),GTK_STOCK_SAVE,1);
 	button_inst_remove=gtk_dialog_add_button(GTK_DIALOG(instwin),GTK_STOCK_REMOVE,2);
-	button_inst_cancel=gtk_dialog_add_button(GTK_DIALOG(instwin),GTK_STOCK_CANCEL,0);	
 	gtk_dialog_set_default_response(GTK_DIALOG(instwin),1);
 	gtk_widget_show(hbox);
 #endif
