@@ -39,7 +39,7 @@ int addAllOptions(cups_option_t **optionsptr, int num_options);
 void setPrinterAsDefault(char *printername);
 int saveOptions(char *printername, int onlyglobal);
 void setDefaults(void);
-int freadline(FILE *file, unsigned char *String, unsigned howmuch);
+int freadline(FILE *file, char *String, unsigned howmuch);
 int getPPDOpts(char *printername);
 void resetButton(GtkWidget *widget, gpointer data);
 void CreateWidgets(void);
