@@ -48,6 +48,9 @@
 GtkWidget *gtklpTab;
 GtkWidget *gtklpViewable,*gtklpViewOut,*gtklpViewText,*gtklpViewImage,*gtklpViewHpgl2,*gtklpViewSpecial,*gtklpViewPPD;
 GtkWidget *prefsFrame,*remPrinterCheck,*remTabCheck,*saveExitCheck,*jobIDOnExitCheck,*wantconstCheck,*saveAnzCheck;
+#if GTK_MAJOR_VERSION != 1
+GtkWidget *saveSizePosCheck;
+#endif
 GtkWidget *pathesFrame;
 GtkWidget *helpFrame;
 GtkWidget *aboutWin;
@@ -138,6 +141,12 @@ void gtklpTabSetDefaults(void)
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wantconstCheck),1);
 				else
 					gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(wantconstCheck),0);
+#if GTK_MAJOR_VERSION != 1
+	if(wantSaveSizePos)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(saveSizePosCheck),1);
+	else
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(saveSizePosCheck),0);
+#endif
 		
 	if(needFileSelection==0)
 	{
@@ -318,7 +327,6 @@ void GtklpViewable(GtkWidget *container)
         gtk_signal_connect(GTK_OBJECT(gtklpViewPPD),"toggled",GTK_SIGNAL_FUNC(gtklpViewChanged),"PPD");
         gtk_widget_show(gtklpViewPPD);
 
-
 }
 
 void prefsChanged(GtkWidget *widget,gpointer data)
@@ -399,6 +407,17 @@ void prefsChanged(GtkWidget *widget,gpointer data)
 					return;
 				}
 
+#if GTK_MAJOR_VERSION != 1
+				if(strcmp((char *)data,"SSP") == 0)
+				{
+					if(wantSaveSizePos == 0)
+						wantSaveSizePos=1;
+					else
+						wantSaveSizePos=0;
+
+					return;
+				}	
+#endif
 
 	if(DEBUG)
 		printf("PROG-ERROR: Unknown prefsChange !\n");
@@ -489,7 +508,13 @@ void PrefsFrame(GtkWidget *container)
 				gtk_box_pack_end(GTK_BOX(constbox), buttonCons, TRUE, TRUE, 0);
 				gtk_signal_connect(GTK_OBJECT(buttonCons),"pressed",GTK_SIGNAL_FUNC(constButton),NULL);
 				gtk_widget_show(buttonCons);
-				
+
+#if GTK_MAJOR_VERSION != 1
+				saveSizePosCheck=gtk_check_button_new_with_label(str2str(_("Remember size and position")));
+				gtk_box_pack_start(GTK_BOX(vbox), saveSizePosCheck, FALSE, FALSE, 0);
+				gtk_signal_connect(GTK_OBJECT(saveSizePosCheck),"pressed",GTK_SIGNAL_FUNC(prefsChanged),"SSP");
+				gtk_widget_show(saveSizePosCheck);
+#endif				
 
 }
 
