@@ -27,6 +27,7 @@
 
 #include <stdio.h>
 #include <cups/cups.h>
+#include <cups/ppd.h>
 #include <cups/language.h>
 #include <gtk/gtk.h>
 #include <unistd.h>
@@ -59,8 +60,6 @@
 #include "gtklpq_accept_job.xpm"
 #include "gtklpq_reject_job.xpm"
 
-char PortString[MAX_PORT+11];
-
 int hasAskedPWD;
 int cancelmode=0;
 
@@ -100,14 +99,12 @@ int main(int argc,char *argv[])
 	GdkBitmap *mgtklpq_exit,*mgtklpq_move,*mgtklpq_prio, *mgtklpq_stop_job, *mgtklpq_stop_jobs;
 	GtkWidget *image;
 	int i1;
-	char Path[MAXPATH+1];
 	char *z1;
 	int queryIntervall=0;
 	int xpos,ypos;
 	char tmpenv[MAX_SERVER_NAME+13];
 	int forceX;
 	int calledGtkLPQ;
-	int calledLpq;
 	int calledLprm;
 	int calledEnable;
 	int calledAccept;
@@ -148,7 +145,6 @@ int main(int argc,char *argv[])
 
 	/*-- See how we are called */
 	calledGtkLPQ=1;
-	calledLpq=0;
 	calledLprm=0;
 	calledEnable=0;
 	calledAccept=0;
@@ -157,7 +153,6 @@ int main(int argc,char *argv[])
 	calledReject=0;
 	if(strcmp(basename(argv[0]),"lpq") == 0) {
 		calledGtkLPQ=0;
-		calledLpq=1;
 		if(forceX == 0)   /* Default: No X when called as lp */
 			nox=1;
 		if(DEBUG)
@@ -236,8 +231,9 @@ int main(int argc,char *argv[])
 	/*--- Get Programm Options ---*/
 	DEF_PRN[0]=(uintptr_t)NULL;
 	ServerName[0]=(uintptr_t)NULL;
+	PortString[0]=(uintptr_t)NULL;
+	ServerAddr[0]=(uintptr_t)NULL;
 	UserName[0]=(uintptr_t)NULL;
-	Path[0]=(uintptr_t)NULL;
 	passWord[0]=(uintptr_t)NULL;
 	i1=getopt(argc,argv,GTKLPQ_ProgOpts);
 	while(i1 != -1)
@@ -263,6 +259,7 @@ int main(int argc,char *argv[])
 						printf("Using port: %s\n",optarg);
 					snprintf(PortString,(size_t)MAX_PORT+10,"IPP_PORT=%s",optarg);
 					putenv(PortString);
+					snprintf(PortString,(size_t)MAX_PORT+10,"%s",optarg);
 				}
 			break;	
 			case 'P':
@@ -393,17 +390,22 @@ int main(int argc,char *argv[])
 		if(DEBUG)
 			printf("connected\n");
 
-    if(stat(ServerName,&snstat) != 0) { 
-      if(DEBUG)
-        printf("PROG-ERROR: Cannot stat %s!\n",ServerName);
-    } else {
-      if(S_ISSOCK(snstat.st_mode)) {
-        strncpy(ServerName,"127.0.0.1",(size_t)MAX_SERVER_NAME);
-      } else {
-        printf("No socket\n");
-      }
-    }
-    
+	if ((stat(ServerName,&snstat) == 0) && S_ISSOCK(snstat.st_mode)) {
+	    /* Unix socket */
+	    if(DEBUG)
+	      printf("Socket found: %s\n",ServerName);
+	      strncpy(ServerName,"127.0.0.1",(size_t)MAX_SERVER_NAME);
+	} else {
+	    if(DEBUG)
+	      printf("Not a socket: %s\n",ServerName);
+	}
+
+	if (PortString[0]) { /* port specified */
+          sprintf(ServerAddr,"%s:%s",ServerName,PortString+9);
+	} else {
+          strcpy(ServerAddr,ServerName);
+	}
+
     snprintf(tmpenv,(size_t)MAX_SERVER_NAME+12,"CUPS_SERVER=%s",ServerName);
     putenv(tmpenv);
     cupsSetServer((const char *)ServerName);
@@ -567,7 +569,6 @@ int main(int argc,char *argv[])
 
 	if(nox == 0) {
   	calledGtkLPQ=1;
-  	calledLpq=0;
   	calledLprm=0;
   	calledEnable=0;
 		calledAccept=0;
