@@ -28,6 +28,7 @@
 #include <stdlib.h>
 #include <gtk/gtk.h>
 #include <cups/cups.h>
+#include <cups/ppd.h>
 
 #include <gettext.h>
 #include <libgtklp.h>
@@ -344,8 +345,8 @@ void printerStatus (char *URI)
 	}
 
   request = ippNew ();
-  request->request.op.operation_id = IPP_GET_PRINTER_ATTRIBUTES;
-  request->request.op.request_id = 1;
+  ippSetOperation(request, IPP_GET_PRINTER_ATTRIBUTES);
+  ippSetRequestId(request, 1);
   ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
 		"attributes-charset", NULL, cupsLangEncoding (cupsLanguage));
   ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
@@ -359,7 +360,7 @@ void printerStatus (char *URI)
 	  != NULL)
 	{
 		aktPrinterHold=0;
-	  switch (attr->values[0].integer)
+	  switch (ippGetInteger (attr, 0))
 	    {
 	    case IPP_PRINTER_IDLE:
 	      strncpy (toolstring, str2str(_("Printer Idle")),(size_t)MAXLINE);
@@ -372,17 +373,17 @@ void printerStatus (char *URI)
 				aktPrinterHold=1;
 	      break;
 	    default:
-	      snprintf (toolstring, (size_t)MAXLINE, "%i", attr->values[0].integer);
+	      snprintf (toolstring, (size_t)MAXLINE, "%i", ippGetInteger (attr, 0));
 	      break;
 	    }
 
 		jobsRejected=0;
 		attr = ippFindAttribute (response, "printer-is-accepting-jobs", IPP_TAG_ZERO);
 		if(attr != NULL) {
-			if(attr->values[0].integer == 0)
+			if(ippGetInteger (attr, 0) == 0)
 				jobsRejected=1;
 			if(DEBUG)
-				printf("Attr=%s: %i\n",attr->name,attr->values[0].integer);
+				printf("Attr=printer-is-accepting-jobs: %i\n",ippGetInteger (attr, 0));
 		}
 
 		if(nox == 0) {
@@ -428,8 +429,8 @@ void printerStatus (char *URI)
 
   if ( (attr = ippFindAttribute (response, "printer-state-message", IPP_TAG_ZERO)) != NULL)
 	{
-		if ((strlen (toolstring) + strlen (attr->values[0].string.text)) < MAXLINE)
-	  	snprintf (toolstring, (size_t)MAXLINE, "%s - %s", toolstring, attr->values[0].string.text);
+		if ((strlen (toolstring) + strlen (ippGetString (attr, 0, NULL))) < MAXLINE)
+	  	snprintf (toolstring, (size_t)MAXLINE, "%s - %s", toolstring, ippGetString (attr, 0, NULL));
 		}
 		if(nox == 0)
       m_id_state = gtk_statusbar_push ((GtkStatusbar *) statbar, c_id_state, (const char *) str2str(toolstring));
@@ -492,10 +493,20 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 	char *z1;
 	int i1=0,l1=0,l2=0,l3=0,l4=0,l5=0,l6=0,l7=0;
 
-  int id = 0;
   gchar queryLine[7][MAXLINE + 1];
   gchar *g[7];
   int queueIsSel = 0;
+  static const char *jattrs[] =	{
+    "copies",
+    "job-name",
+    "job-originating-user-name",
+    "job-printer-uri",
+    "job-state",
+    "job-k-octets",
+    "job-id",
+    "job-priority",
+    "job-state"
+  };
 
   if(DEBUG)
 	printf("Update...\n");
@@ -508,10 +519,10 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
   	  gtk_statusbar_remove ((GtkStatusbar *) statbar, c_id_upd, m_id_upd);
 	}
 	
-  request = ippNew ();
-  request->request.op.operation_id =
-    id ? IPP_GET_JOB_ATTRIBUTES : IPP_GET_JOBS;
-  request->request.op.request_id = 1;
+  request = ippNewRequest(IPP_GET_JOBS);
+  ippSetRequestId(request, 1);
+
+
   language = cupsLangDefault ();
   attr =
     ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
@@ -519,17 +530,16 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
   attr =
     ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,
 		  "attributes-natural-language", NULL, language->language);
-  if (strlen (ServerName) + strlen (PortString) + strlen (PrinterNames[PrinterChoice] + 20) < MAX_URI)
+
+  if (strlen (ServerAddr) + strlen (PrinterNames[PrinterChoice] + 20) < MAX_URI)
     {
 			z1=strchr(PrinterNames[PrinterChoice],'/');
 			if(z1 != NULL)
 				*z1=(uintptr_t)NULL;		
-      if (PortString[0] != (uintptr_t) NULL)
-				snprintf (resource, (size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString, PrinterNames[PrinterChoice]);
-      else
-				snprintf (resource, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerName, PrinterNames[PrinterChoice]);
+			snprintf (resource, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerAddr, PrinterNames[PrinterChoice]);
 			if(z1 != NULL)
 				*z1='/';
+
 			 printerStatus (resource);
     }
   else
@@ -542,6 +552,10 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
   ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_URI, "printer-uri", NULL,
 		resource);
 
+
+  ippAddStrings(request, IPP_TAG_OPERATION, IPP_TAG_KEYWORD,"requested-attributes",(sizeof(jattrs) / sizeof(jattrs[0])), NULL, jattrs);
+
+
   jobcount = 0;
 
 	if(nox == 0)
@@ -549,12 +563,12 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 
   if ((response = cupsDoRequest (cupsHttp, request, "/")) != NULL)
     {
-      if (response->request.status.status_code > IPP_OK_CONFLICT)
+      if (ippGetStatusCode(response) > IPP_OK_CONFLICT)
 	{
 		if(nox == 0)
-		  m_id_upd = gtk_statusbar_push ((GtkStatusbar *) statbar, c_id_upd, str2str((char *)ippErrorString(response->request.status.status_code)));
+		  m_id_upd = gtk_statusbar_push ((GtkStatusbar *) statbar, c_id_upd, str2str((char *)ippErrorString(ippGetStatusCode(response))));
 		else
-			g_print("[%s] %s: %s\n\n",PrinterNames[PrinterChoice], str2str(_("Error")),ippErrorString (response->request.status.status_code));
+			g_print("[%s] %s: %s\n\n",PrinterNames[PrinterChoice], str2str(_("Error")),ippErrorString (ippGetStatusCode(response)));
 	  ippDelete (response);
 	  return(FALSE);
 	}
@@ -623,10 +637,11 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 		}
 
       rank = 1;
-      for (attr = response->attrs; attr != NULL; attr = attr->next)
+      for (attr = ippFirstAttribute (response); attr != NULL; attr = ippNextAttribute (response))
 	{
-	  while (attr != NULL && attr->group_tag != IPP_TAG_JOB)
-	    attr = attr->next;
+	  while (attr != NULL && ippGetGroupTag (attr) != IPP_TAG_JOB)
+	    attr = ippNextAttribute (response);
+
 	  if (attr == NULL)
 	    break;
 
@@ -634,43 +649,36 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 	  jobsize = 0;
 	  jobstate = IPP_JOB_PENDING;
 	  jobname = str2str(_("Untitled"));
-	  jobuser = NULL;
+	  jobuser = "()"; 
 	  jobdest = NULL;
 	  jobcopies = 1;
 
-	  while (attr != NULL && attr->group_tag == IPP_TAG_JOB)
+	  while (attr != NULL && ippGetGroupTag (attr) == IPP_TAG_JOB)
 	    {
-	      if (strcmp (attr->name, "job-id") == 0 &&
-		  attr->value_tag == IPP_TAG_INTEGER)
-		jobid = attr->values[0].integer;
+    if (strcmp (ippGetName (attr), "job-id") == 0 && ippGetValueTag (attr) == IPP_TAG_INTEGER)
+      jobid = ippGetInteger (attr, 0);
 
-	      if (strcmp (attr->name, "job-k-octets") == 0 &&
-		  attr->value_tag == IPP_TAG_INTEGER)
-		jobsize = attr->values[0].integer * 1024;
 
-	      if (strcmp (attr->name, "job-state") == 0 &&
-		  attr->value_tag == IPP_TAG_ENUM)
-		jobstate = (ipp_jstate_t) attr->values[0].integer;
+    if (strcmp (ippGetName (attr), "job-k-octets") == 0 && ippGetValueTag (attr) == IPP_TAG_INTEGER)
+      jobsize = ippGetInteger (attr, 0) * 1024;
 
-	      if (strcmp (attr->name, "job-printer-uri") == 0 &&
-		  attr->value_tag == IPP_TAG_URI)
-		if ((jobdest = strrchr (attr->values[0].string.text, '/')) !=
-		    NULL)
-		  jobdest++;
+    if (strcmp (ippGetName (attr), "job-state") == 0 && ippGetValueTag (attr) == IPP_TAG_ENUM)
+      jobstate = (ipp_jstate_t) ippGetInteger (attr, 0);
 
-	      if (strcmp (attr->name, "job-originating-user-name") == 0 &&
-		  attr->value_tag == IPP_TAG_NAME)
-		jobuser = attr->values[0].string.text;
+    if (strcmp (ippGetName (attr), "job-printer-uri") == 0 && ippGetValueTag (attr) == IPP_TAG_URI)
+      if ((jobdest = strrchr (ippGetString (attr, 0, NULL), '/')) != NULL)
+		    jobdest++;
 
-	      if (strcmp (attr->name, "job-name") == 0 &&
-		  attr->value_tag == IPP_TAG_NAME)
-		jobname = attr->values[0].string.text;
+    if (strcmp (ippGetName (attr), "job-originating-user-name") == 0 && ippGetValueTag (attr) == IPP_TAG_NAME)
+      jobuser = ippGetString (attr, 0, NULL);
 
-	      if (strcmp (attr->name, "copies") == 0 &&
-		  attr->value_tag == IPP_TAG_INTEGER)
-		jobcopies = attr->values[0].integer;
+    if (strcmp (ippGetName (attr), "job-name") == 0 && ippGetValueTag (attr) == IPP_TAG_NAME)
+      jobname = ippGetString (attr, 0, NULL);
 
-	      attr = attr->next;
+    if (strcmp (ippGetName (attr), "copies") == 0 && ippGetValueTag (attr) == IPP_TAG_INTEGER)
+      jobcopies = ippGetInteger (attr, 0);
+
+	      attr = ippNextAttribute (response);
 	    }
 
 	  if (jobdest == NULL || jobid == 0)
@@ -716,6 +724,7 @@ int printQueueUpdate (GtkWidget * widget, gpointer data)
 	      snprintf (queryLine[0], (size_t)MAXLINE, "%i", i1);
 	      break;
 	    }
+
 	  strncpy (queryLine[1], str2str(rankstr),(size_t)MAXLINE);
 	  strncpy (queryLine[2], str2str((char *)jobuser),(size_t)MAXLINE);
 	  snprintf (queryLine[3], (size_t)MAXLINE, "%d", jobid);
@@ -1077,20 +1086,18 @@ int jobAttr(int job_id, int num_options, cups_option_t *options)
 	cups_lang_t *language;
 
 	request = ippNew();
-	request->request.op.operation_id = IPP_SET_JOB_ATTRIBUTES;
-	request->request.op.request_id   = 1;
+  ippSetOperation(request, IPP_SET_JOB_ATTRIBUTES);
+  ippSetRequestId(request, 1);	
+	
 
 	language = cupsLangDefault ();
 	
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,"attributes-charset", NULL, cupsLangEncoding(language));
 	ippAddString(request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE,"attributes-natural-language", NULL, language->language);
 	
-	if ((strlen (ServerName) + strlen (PortString) +  25) < MAX_URI)
+	if ((strlen (ServerAddr) +  25) < MAX_URI)
 	{
-		if (PortString[0] != (uintptr_t) NULL)
-			snprintf (uri, (size_t)MAX_URI, "ipp://%s:%s/jobs/%i", ServerName, PortString, job_id);
-		else
-			snprintf (uri, (size_t)MAX_URI, "ipp://%s/jobs/%i", ServerName, job_id);
+		snprintf (uri, (size_t)MAX_URI, "ipp://%s/jobs/%i", ServerAddr, job_id);
 		if(DEBUG)
 			printf("uri: %s\n",uri);
 	}
@@ -1108,10 +1115,10 @@ int jobAttr(int job_id, int num_options, cups_option_t *options)
 	
 	if ((response = cupsDoRequest(cupsHttp, request, "/jobs")) != NULL)
 	{
-		if (response->request.status.status_code > IPP_OK_CONFLICT)
+		if (ippGetStatusCode (response) > IPP_OK_CONFLICT)
 		{
 			if(DEBUG)
-				printf("set-job-attributes failed(1): %s\n",ippErrorString(response->request.status.status_code));
+				printf("set-job-attributes failed(1): %s\n",ippErrorString(ippGetStatusCode (response)));
 			quick_message(str2str(_("Unable to change priority!")),2);
 			ippDelete(response);
 			return (1);
@@ -1163,7 +1170,6 @@ void jobPrio (GtkWidget *dialog)
 void cancelJob (GtkWidget * dialog)
 {
   int job_id;			/* Job ID */
-  const char *dest;		/* Destination printer */
   char uri[MAX_URI+1];		/* Printer or job URI */
 	char touri[MAX_URI+1];
   ipp_t *request;		/* IPP request */
@@ -1228,15 +1234,14 @@ void cancelJob (GtkWidget * dialog)
 			return;
 		break;
 	}
-  dest = NULL;
   response = NULL;
 
 	if(dialog != (GtkWidget *)NULL)
 		gtk_widget_destroy (dialog);
 	
 	request = ippNew ();
-	request->request.op.operation_id = op;
-	request->request.op.request_id = 1;
+	ippSetOperation(request, op);
+	ippSetRequestId(request, 1);
 	language = cupsLangDefault ();
 	ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_CHARSET,
 		      "attributes-charset", NULL,
@@ -1245,7 +1250,7 @@ void cancelJob (GtkWidget * dialog)
 		      "attributes-natural-language", NULL,
 		      language->language);
 
-  if ((strlen (ServerName) + strlen (PortString) +  25) < MAX_URI)
+  if ((strlen (ServerAddr) +  25) < MAX_URI)
   {
 		z1=strchr(PrinterNames[PrinterChoice],'/');
 		z2=strchr(PrinterNames[PrtDlgSel],'/');
@@ -1253,16 +1258,8 @@ void cancelJob (GtkWidget * dialog)
 			*z1=(uintptr_t)NULL;
 		if(z2 != NULL)
 			*z2=(uintptr_t)NULL;	
-	  if (PortString[0] != (uintptr_t) NULL)
-		{
-		  snprintf (uri, (size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString,  PrinterNames[PrinterChoice]);
-			snprintf (touri,(size_t)MAX_URI, "ipp://%s:%s/printers/%s", ServerName, PortString,  PrinterNames[PrtDlgSel]);
-		}
-    else
-		{
-		  snprintf (uri, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerName, PrinterNames[PrinterChoice]);
-			snprintf (touri, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerName, PrinterNames[PrtDlgSel]);
-		}
+		snprintf (uri, (size_t)MAX_URI, "ipp://%s/printers/%s", ServerAddr, PrinterNames[PrinterChoice]);
+		snprintf (touri,(size_t)MAX_URI, "ipp://%s/printers/%s", ServerAddr, PrinterNames[PrtDlgSel]);
 		if(z1 != NULL)
 			*z1='/';
 		if(z2 != NULL)
@@ -1310,7 +1307,7 @@ void cancelJob (GtkWidget * dialog)
 
 	if (response != NULL)
 	  {
-	    switch (response->request.status.status_code)
+	    switch (ippGetStatusCode (response))
 	      {
 	      case IPP_NOT_FOUND:
 					quick_message(str2str(_("Job or printer not found!")),2);
@@ -1321,8 +1318,8 @@ void cancelJob (GtkWidget * dialog)
 	      case IPP_FORBIDDEN:
 					quick_message(str2str(_("You don't own this job!")),2);
 		break;
-	      default:
-		if (response->request.status.status_code > IPP_OK_CONFLICT)
+	  default:
+		  if (ippGetStatusCode (response) > IPP_OK_CONFLICT)
 					quick_message(str2str(_("Unable to do so!")),2);
 		break;
 	      }
