@@ -70,14 +70,18 @@ int PrinterChoice;
 int PrinterNum;
 int lastPrinterChoice;
 int passActive=0;
+char UserName[MAX_USERNAME+1];
 char passWord[MAX_PASSLEN+1];
 char ServerName[MAX_SERVER_NAME+1];
+char PortString[MAX_PORT+11];
+char ServerAddr[MAX_SERVER_NAME+MAX_PORT+1];
 char DEF_PRN[DEF_PRN_LEN+1];
 char PrinterBannerStart[MAX_PRT][MAXLINE+1];
 char PrinterBannerEnd[MAX_PRT][MAXLINE+1];
 char PrinterInfos[MAX_PRT][MAXLINE+1];
 char PrinterLocations[MAX_PRT][MAXLINE+1];
 char PrinterNames[MAX_PRT][DEF_PRN_LEN+1];
+char PrinterFavNames[MAX_PRT][DEF_PRN_LEN+1];
 
 #if GTK_MAJOR_VERSION != 1
 GtkWidget *passwin;
@@ -98,8 +102,6 @@ int maxPassTry=0;
 extern int hasAskedPWD;
 extern GtkWidget *dialog;
 
-char UserName[MAX_USERNAME+1];
-
 void quick_message(gchar *message, int which) 
 {
   GtkWidget *label, *pixmapwid, *vbox, *hbox;
@@ -198,6 +200,66 @@ void quick_message(gchar *message, int which)
 #endif
 }
 
+void checkFavorites(void)
+{
+        int i1,i2,found;
+
+	/* Check list of favorites, remove no longer existing entries */
+	if(DEBUG)
+        	printf("Checking favorites\n");
+	i1=0;
+	while(PrinterFavNames[i1][0] != (uintptr_t)NULL)
+	{
+        	i2=0;
+        	found=0;
+        	do
+        	{
+        		if(strcmp(str2str(PrinterNames[i2]),str2str(PrinterFavNames[i1])) == 0)
+        		{
+        			found = 1;
+        			break;
+        		}
+        		i2++;
+        	}
+        	while(PrinterNames[i2][0] != (uintptr_t)NULL);
+
+        	if (!found) {
+        	        /* find last entry and move here */
+        	        unsigned i3;
+
+        		if(DEBUG)
+        			printf("Remove %s from favorites\n", PrinterFavNames[i1]);
+        	        i3 = i1 + 1;
+        	        while (PrinterFavNames[i3][0] != (uintptr_t)NULL)
+        	                i3++;
+                        i3--;
+                        if (i3 != i1)
+                        {
+                                strcpy(PrinterFavNames[i1], PrinterFavNames[i3]);
+                        }
+                        else
+                        {
+                		i1++;
+                        }
+                        PrinterFavNames[i3][0] = 0;
+        	}
+        	else
+        	{
+        		i1++;
+                }
+	}
+	if(DEBUG)
+	{
+	        printf("Favorites now:\n");
+        	i1=0;
+        	while(PrinterFavNames[i1][0] != (uintptr_t)NULL)
+        	{
+        	        printf("%u: %s\n", i1, PrinterFavNames[i1]);
+        		i1++;
+        	}
+	}
+}
+
 void getPrinters(int loop)
 {
   int i1;
@@ -230,7 +292,8 @@ void getPrinters(int loop)
 	{
 		if(DEBUG)
 			printf("PROG-ERROR: Too many printers: %u !\n",PrinterNum);
-		exitOnError(str2str(_("You have installed too many printers or templates !")),"",-3);
+/*		exitOnError(str2str(_("You have installed too many printers or templates !")),"",-3); */
+                PrinterNum = MAX_PRT;
 	}
 	PrinterNum--;
 	if(DEBUG)
@@ -343,10 +406,10 @@ void getPrinters(int loop)
 			if(strcmp(DEF_PRN,tmpprn) == 0)
 				PrinterChoice=i1-droppedPrinters;
 		}
-		snprintf(URI,(size_t)MAX_URI,"ipp://%s/printers/%s",ServerName,dests[i1].name);
+		snprintf(URI,(size_t)MAX_URI,"ipp://%s/printers/%s",ServerAddr,dests[i1].name);
 		request=ippNew();
-		request->request.op.operation_id=IPP_GET_PRINTER_ATTRIBUTES;
-		request->request.op.request_id=1;
+		ippSetOperation(request, IPP_GET_PRINTER_ATTRIBUTES);
+		ippSetRequestId(request, 1);
 		ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_CHARSET,"attributes-charset",NULL,cupsLangEncoding(cupsLanguage));
 		ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_LANGUAGE,"attributes-natural-language",NULL,cupsLanguage->language);
 		ippAddString(request,IPP_TAG_OPERATION,IPP_TAG_URI,"printer-uri",NULL,URI);
@@ -359,9 +422,10 @@ void getPrinters(int loop)
 		if((attr=ippFindAttribute(response,"job-sheets-default",IPP_TAG_ZERO)) != NULL)
 		{
 			if(DEBUG)
-				printf("Job-Sheets-Default for %s\n  Start: %s\n  Stop: %s\n",dests[i1].name,attr->values[0].string.text,attr->values[1].string.text);
-			strncpy(PrinterBannerStart[i1-droppedPrinters],attr->values[0].string.text,(size_t)MAXLINE);
-			strncpy(PrinterBannerEnd[i1-droppedPrinters],attr->values[1].string.text,(size_t)MAXLINE);
+			   printf("Job-Sheets-Default for %s\n  Start: %s\n  Stop: %s\n",dests[i1].name,ippGetString (attr, 0, NULL),ippGetString (attr, 1, NULL));	
+			strncpy(PrinterBannerStart[i1-droppedPrinters],ippGetString (attr, 0, NULL),(size_t)MAXLINE);
+      strncpy(PrinterBannerEnd[i1-droppedPrinters],ippGetString (attr, 1, NULL),(size_t)MAXLINE);
+			
 		}
 		else
 		{
@@ -373,8 +437,8 @@ void getPrinters(int loop)
 		if((attr=ippFindAttribute(response,"printer-location",IPP_TAG_ZERO)) != NULL)
 		{
 			if(DEBUG)
-				printf("Location: %s\n",attr->values[0].string.text);
-			strncpy(PrinterLocations[i1-droppedPrinters],attr->values[0].string.text,(size_t)MAXLINE);
+				printf("Location: %s\n",ippGetString (attr, 0, NULL));
+			strncpy(PrinterLocations[i1-droppedPrinters],ippGetString (attr, 0, NULL),(size_t)MAXLINE);
 		}
 		else
 		{
@@ -384,8 +448,8 @@ void getPrinters(int loop)
 		if((attr=ippFindAttribute(response,"printer-info",IPP_TAG_ZERO)) != NULL)
 		{
 			if(DEBUG)
-				printf("Info: %s\n",attr->values[0].string.text);	
-			strncpy(PrinterInfos[i1-droppedPrinters],attr->values[0].string.text,(size_t)MAXLINE);
+			  printf("Info: %s\n",ippGetString (attr, 0, NULL));	
+			strncpy(PrinterInfos[i1-droppedPrinters],ippGetString (attr, 0, NULL),(size_t)MAXLINE);
 		}
 		else
 		{
@@ -431,6 +495,7 @@ void getPrinters(int loop)
 			printf("PROG-ERROR: No Printers found !\n");
 		exitOnError(str2str(_("No printers found !")),"",-2);
 	}
+	checkFavorites();
 }
 
 void gtklp_fatal_end(char *text)
